==> jc-1.4.0.tar.gz: gnu/xml/libxmlj/dom/GnomeXPathExpression.h <==
// class gnu.xml.libxmlj.dom.GnomeXPathExpression

// class file dependencies
// @dep_class f4a62cc783331996 gnu_xml_libxmlj_dom_GnomeXPathExpression
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_xml_libxmlj_dom_GnomeXPathExpression_H_
#define _JC_gnu_xml_libxmlj_dom_GnomeXPathExpression_H_

// Forward structure declarations
struct _jc_gnu_xml_libxmlj_dom_GnomeDocument$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_org_w3c_dom_Node$object;
struct _jc_org_w3c_dom_xpath_XPathNSResolver$object;

// Typedefs
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeXPathExpression$sub_refs	_jc_gnu_xml_libxmlj_dom_GnomeXPathExpression$sub_refs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeXPathExpression$sub_nonrefs	_jc_gnu_xml_libxmlj_dom_GnomeXPathExpression$sub_nonrefs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeXPathExpression$refs	_jc_gnu_xml_libxmlj_dom_GnomeXPathExpression$refs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeXPathExpression$nonrefs	_jc_gnu_xml_libxmlj_dom_GnomeXPathExpression$nonrefs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeXPathExpression$object	_jc_gnu_xml_libxmlj_dom_GnomeXPathExpression$object;

typedef const struct _jc_gnu_xml_libxmlj_dom_GnomeXPathExpression$vmethods	_jc_gnu_xml_libxmlj_dom_GnomeXPathExpression$vmethods;
typedef const struct _jc_gnu_xml_libxmlj_dom_GnomeXPathExpression$vtable	_jc_gnu_xml_libxmlj_dom_GnomeXPathExpression$vtable;
typedef const struct _jc_gnu_xml_libxmlj_dom_GnomeXPathExpression$vtype	_jc_gnu_xml_libxmlj_dom_GnomeXPathExpression$vtype;

// Constructors
extern void _jc_gnu_xml_libxmlj_dom_GnomeXPathExpression$method$_init$1ff30937b69a050a(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeXPathExpression$object *, struct _jc_gnu_xml_libxmlj_dom_GnomeDocument$object *, struct _jc_java_lang_String$object *, struct _jc_object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_gnu_xml_libxmlj_dom_GnomeXPathExpression$method$doEvaluate$8d0df87a43fbbe17(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeXPathExpression$object *, struct _jc_java_lang_Object$object *, struct _jc_object *, jshort, struct _jc_java_lang_Object$object *);
extern struct _jc_java_lang_Object$object *_jc_gnu_xml_libxmlj_dom_GnomeXPathExpression$method$evaluate$7532129f49cc376f(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeXPathExpression$object *, struct _jc_object *, jshort, struct _jc_java_lang_Object$object *);
extern void _jc_gnu_xml_libxmlj_dom_GnomeXPathExpression$method$finalize$660a5b5b608ff21f(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeXPathExpression$object *);
extern void _jc_gnu_xml_libxmlj_dom_GnomeXPathExpression$method$free$300db1a5a8d912a8(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeXPathExpression$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_java_lang_Object$object *_jc_gnu_xml_libxmlj_dom_GnomeXPathExpression$method$init$08fbef221b9794f2(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeXPathExpression$object *, struct _jc_java_lang_String$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_libxmlj_dom_GnomeXPathExpression$method_info$doEvaluate$8d0df87a43fbbe17;
extern _jc_method _jc_gnu_xml_libxmlj_dom_GnomeXPathExpression$method_info$evaluate$7532129f49cc376f;
extern _jc_method _jc_gnu_xml_libxmlj_dom_GnomeXPathExpression$method_info$finalize$660a5b5b608ff21f;
extern _jc_method _jc_gnu_xml_libxmlj_dom_GnomeXPathExpression$method_info$free$300db1a5a8d912a8;
extern _jc_method _jc_gnu_xml_libxmlj_dom_GnomeXPathExpression$method_info$init$08fbef221b9794f2;

// Virtual methods structure
struct _jc_gnu_xml_libxmlj_dom_GnomeXPathExpression$vmethods {
	struct _jc_java_lang_Object$object	*(*doEvaluate$8d0df87a43fbbe17)(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeXPathExpression$object *, struct _jc_java_lang_Object$object *, struct _jc_object *, jshort, struct _jc_java_lang_Object$object *);
	struct _jc_java_lang_Object$object	*(*evaluate$7532129f49cc376f)(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeXPathExpression$object *, struct _jc_object *, jshort, struct _jc_java_lang_Object$object *);
	void	(*finalize$660a5b5b608ff21f)(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeXPathExpression$object *);
	void	(*free$300db1a5a8d912a8)(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeXPathExpression$object *, struct _jc_java_lang_Object$object *);
	struct _jc_java_lang_Object$object	*(*init$08fbef221b9794f2)(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeXPathExpression$object *, struct _jc_java_lang_String$object *);
};

// Vtable
struct _jc_gnu_xml_libxmlj_dom_GnomeXPathExpression$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_libxmlj_dom_GnomeXPathExpression$vmethods	gnu_xml_libxmlj_dom_GnomeXPathExpression;
};

// Vtype
struct _jc_gnu_xml_libxmlj_dom_GnomeXPathExpression$vtype {
	_jc_type			type;
	_jc_gnu_xml_libxmlj_dom_GnomeXPathExpression$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_libxmlj_dom_GnomeXPathExpression$sub_refs {
	struct _jc_java_lang_Object$object	*expr;
};

// Reference instance fields (object)
struct _jc_gnu_xml_libxmlj_dom_GnomeXPathExpression$refs {
    _jc_gnu_xml_libxmlj_dom_GnomeXPathExpression$sub_refs	gnu_xml_libxmlj_dom_GnomeXPathExpression;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_libxmlj_dom_GnomeXPathExpression$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_libxmlj_dom_GnomeXPathExpression$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_libxmlj_dom_GnomeXPathExpression$sub_nonrefs	gnu_xml_libxmlj_dom_GnomeXPathExpression;
};

// Object instance structure
struct _jc_gnu_xml_libxmlj_dom_GnomeXPathExpression$object {
	_jc_gnu_xml_libxmlj_dom_GnomeXPathExpression$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_libxmlj_dom_GnomeXPathExpression$vtype	*vtype;
	_jc_gnu_xml_libxmlj_dom_GnomeXPathExpression$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_libxmlj_dom_GnomeXPathExpression$vtype _jc_gnu_xml_libxmlj_dom_GnomeXPathExpression$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_libxmlj_dom_GnomeXPathExpression, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_libxmlj_dom_GnomeXPathExpression$class_object;

#endif	/* _JC_gnu_xml_libxmlj_dom_GnomeXPathExpression_H_ */

==> jc-1.4.6.tar.gz: gnu/xml/libxmlj/dom/GnomeXPathExpression.h <==
// class gnu.xml.libxmlj.dom.GnomeXPathExpression

// class file dependencies
// @dep_class f4a62cc783331996 gnu_xml_libxmlj_dom_GnomeXPathExpression
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_xml_libxmlj_dom_GnomeXPathExpression_H_
#define _JC_gnu_xml_libxmlj_dom_GnomeXPathExpression_H_

// Forward structure declarations
struct _jc_gnu_xml_libxmlj_dom_GnomeDocument$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_org_w3c_dom_Node$object;
struct _jc_org_w3c_dom_xpath_XPathNSResolver$object;

// Typedefs
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeXPathExpression$sub_refs	_jc_gnu_xml_libxmlj_dom_GnomeXPathExpression$sub_refs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeXPathExpression$sub_nonrefs	_jc_gnu_xml_libxmlj_dom_GnomeXPathExpression$sub_nonrefs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeXPathExpression$refs	_jc_gnu_xml_libxmlj_dom_GnomeXPathExpression$refs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeXPathExpression$nonrefs	_jc_gnu_xml_libxmlj_dom_GnomeXPathExpression$nonrefs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeXPathExpression$object	_jc_gnu_xml_libxmlj_dom_GnomeXPathExpression$object;

typedef const struct _jc_gnu_xml_libxmlj_dom_GnomeXPathExpression$vmethods	_jc_gnu_xml_libxmlj_dom_GnomeXPathExpression$vmethods;
typedef const struct _jc_gnu_xml_libxmlj_dom_GnomeXPathExpression$vtable	_jc_gnu_xml_libxmlj_dom_GnomeXPathExpression$vtable;
typedef const struct _jc_gnu_xml_libxmlj_dom_GnomeXPathExpression$vtype	_jc_gnu_xml_libxmlj_dom_GnomeXPathExpression$vtype;

// Constructors
extern void _jc_gnu_xml_libxmlj_dom_GnomeXPathExpression$method$_init$1ff30937b69a050a(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeXPathExpression$object *, struct _jc_gnu_xml_libxmlj_dom_GnomeDocument$object *, struct _jc_java_lang_String$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_gnu_xml_libxmlj_dom_GnomeXPathExpression$method$doEvaluate$8d0df87a43fbbe17(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeXPathExpression$object *, struct _jc_java_lang_Object$object *, struct _jc_object *, jshort, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_gnu_xml_libxmlj_dom_GnomeXPathExpression$method$evaluate$7532129f49cc376f(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeXPathExpression$object *, struct _jc_object *, jshort, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_xml_libxmlj_dom_GnomeXPathExpression$method$finalize$660a5b5b608ff21f(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeXPathExpression$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_xml_libxmlj_dom_GnomeXPathExpression$method$free$300db1a5a8d912a8(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeXPathExpression$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_gnu_xml_libxmlj_dom_GnomeXPathExpression$method$init$08fbef221b9794f2(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeXPathExpression$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_libxmlj_dom_GnomeXPathExpression$method_info$doEvaluate$8d0df87a43fbbe17;
extern _jc_method _jc_gnu_xml_libxmlj_dom_GnomeXPathExpression$method_info$evaluate$7532129f49cc376f;
extern _jc_method _jc_gnu_xml_libxmlj_dom_GnomeXPathExpression$method_info$finalize$660a5b5b608ff21f;
extern _jc_method _jc_gnu_xml_libxmlj_dom_GnomeXPathExpression$method_info$free$300db1a5a8d912a8;
extern _jc_method _jc_gnu_xml_libxmlj_dom_GnomeXPathExpression$method_info$init$08fbef221b9794f2;

// Virtual methods structure
struct _jc_gnu_xml_libxmlj_dom_GnomeXPathExpression$vmethods {
	struct _jc_java_lang_Object$object	*(*doEvaluate$8d0df87a43fbbe17)(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeXPathExpression$object *, struct _jc_java_lang_Object$object *, struct _jc_object *, jshort, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*evaluate$7532129f49cc376f)(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeXPathExpression$object *, struct _jc_object *, jshort, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	void	(*finalize$660a5b5b608ff21f)(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeXPathExpression$object *) _JC_JCNI_ATTR;
	void	(*free$300db1a5a8d912a8)(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeXPathExpression$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*init$08fbef221b9794f2)(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeXPathExpression$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_xml_libxmlj_dom_GnomeXPathExpression$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_libxmlj_dom_GnomeXPathExpression$vmethods	gnu_xml_libxmlj_dom_GnomeXPathExpression;
};

// Vtype
struct _jc_gnu_xml_libxmlj_dom_GnomeXPathExpression$vtype {
	_jc_type			type;
	_jc_gnu_xml_libxmlj_dom_GnomeXPathExpression$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_libxmlj_dom_GnomeXPathExpression$sub_refs {
	struct _jc_java_lang_Object$object	*expr;
};

// Reference instance fields (object)
struct _jc_gnu_xml_libxmlj_dom_GnomeXPathExpression$refs {
    _jc_gnu_xml_libxmlj_dom_GnomeXPathExpression$sub_refs	gnu_xml_libxmlj_dom_GnomeXPathExpression;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_libxmlj_dom_GnomeXPathExpression$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_libxmlj_dom_GnomeXPathExpression$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_libxmlj_dom_GnomeXPathExpression$sub_nonrefs	gnu_xml_libxmlj_dom_GnomeXPathExpression;
};

// Object instance structure
struct _jc_gnu_xml_libxmlj_dom_GnomeXPathExpression$object {
	_jc_gnu_xml_libxmlj_dom_GnomeXPathExpression$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_libxmlj_dom_GnomeXPathExpression$vtype	*vtype;
	_jc_gnu_xml_libxmlj_dom_GnomeXPathExpression$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_libxmlj_dom_GnomeXPathExpression$vtype _jc_gnu_xml_libxmlj_dom_GnomeXPathExpression$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_libxmlj_dom_GnomeXPathExpression, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_libxmlj_dom_GnomeXPathExpression$class_object;

#endif	/* _JC_gnu_xml_libxmlj_dom_GnomeXPathExpression_H_ */
